@@ -3,5 +3,6 @@ Seeders are classes to feed Pipeline
 """
 
 from .csvseeder import CsvSeeder
+from .jsonseeder import JsonSeeder
 
-__all__ = ["CsvSeeder"]
+__all__ = ["CsvSeeder", "JsonSeeder"]
