@@ -5,5 +5,6 @@ writer
 """
 
 from .csvwriter import CsvWriter
+from .jsonwriter import JsonWriter
 
-__all__ = ["CsvWriter"]
+__all__ = ["CsvWriter", "JsonWriter"]
